==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/ResourceSetBindingCreateRequest.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ResourceSetBindingCreateRequest
 */
@JsonPropertyOrder({ ResourceSetBindingCreateRequest.JSON_PROPERTY_MEMBERS,
        ResourceSetBindingCreateRequest.JSON_PROPERTY_ROLE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class ResourceSetBindingCreateRequest implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_MEMBERS = "members";
    private List<String> members = null;

    public static final String JSON_PROPERTY_ROLE = "role";
    private String role;

    public ResourceSetBindingCreateRequest() {
    }

    public ResourceSetBindingCreateRequest members(List<String> members) {

        this.members = members;
        return this;
    }

    public ResourceSetBindingCreateRequest addmembersItem(String membersItem) {
        if (this.members == null) {
            this.members = new ArrayList<>();
        }
        this.members.add(membersItem);
        return this;
    }

    /**
     * Get members
     *
     * @return members
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_MEMBERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getMembers() {
        return members;
    }

    @JsonProperty(JSON_PROPERTY_MEMBERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setMembers(List<String> members) {
        this.members = members;
    }

    public ResourceSetBindingCreateRequest role(String role) {

        this.role = role;
        return this;
    }

    /**
     * Unique key for the role
     *
     * @return role
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Unique key for the role")
    @JsonProperty(JSON_PROPERTY_ROLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getRole() {
        return role;
    }

    @JsonProperty(JSON_PROPERTY_ROLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRole(String role) {
        this.role = role;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ResourceSetBindingCreateRequest resourceSetBindingCreateRequest = (ResourceSetBindingCreateRequest) o;
        return Objects.equals(this.members, resourceSetBindingCreateRequest.members)
                && Objects.equals(this.role, resourceSetBindingCreateRequest.role);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(members, role);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ResourceSetBindingCreateRequest {\n");
        sb.append("    members: ").append(toIndentedString(members)).append("\n");
        sb.append("    role: ").append(toIndentedString(role)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: com/okta/sdk/resource/model/ResourceSetBindingCreateRequest.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ResourceSetBindingCreateRequest
 */
@JsonPropertyOrder({ ResourceSetBindingCreateRequest.JSON_PROPERTY_MEMBERS,
        ResourceSetBindingCreateRequest.JSON_PROPERTY_ROLE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class ResourceSetBindingCreateRequest implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_MEMBERS = "members";
    private List<String> members = null;

    public static final String JSON_PROPERTY_ROLE = "role";
    private String role;

    public ResourceSetBindingCreateRequest() {
    }

    public ResourceSetBindingCreateRequest members(List<String> members) {

        this.members = members;
        return this;
    }

    public ResourceSetBindingCreateRequest addmembersItem(String membersItem) {
        if (this.members == null) {
            this.members = new ArrayList<>();
        }
        this.members.add(membersItem);
        return this;
    }

    /**
     * Get members
     *
     * @return members
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_MEMBERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getMembers() {
        return members;
    }

    @JsonProperty(JSON_PROPERTY_MEMBERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setMembers(List<String> members) {
        this.members = members;
    }

    public ResourceSetBindingCreateRequest role(String role) {

        this.role = role;
        return this;
    }

    /**
     * Unique key for the role
     *
     * @return role
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Unique key for the role")
    @JsonProperty(JSON_PROPERTY_ROLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getRole() {
        return role;
    }

    @JsonProperty(JSON_PROPERTY_ROLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRole(String role) {
        this.role = role;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ResourceSetBindingCreateRequest resourceSetBindingCreateRequest = (ResourceSetBindingCreateRequest) o;
        return Objects.equals(this.members, resourceSetBindingCreateRequest.members)
                && Objects.equals(this.role, resourceSetBindingCreateRequest.role);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(members, role);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ResourceSetBindingCreateRequest {\n");
        sb.append("    members: ").append(toIndentedString(members)).append("\n");
        sb.append("    role: ").append(toIndentedString(role)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
